@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c 11220 2009-01-25 23:43:11Z callum $ */
+/* $Id: gweather-applet.c 11293 2009-02-17 09:05:47Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -279,12 +279,12 @@ applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
        gtk_widget_destroy (gw_applet->details_dialog);
 
     if (gw_applet->timeout_tag > 0) {
-       gtk_timeout_remove(gw_applet->timeout_tag);
+       g_source_remove(gw_applet->timeout_tag);
        gw_applet->timeout_tag = 0;
     }
 	
     if (gw_applet->suncalc_timeout_tag > 0) {
-       gtk_timeout_remove(gw_applet->suncalc_timeout_tag);
+       g_source_remove(gw_applet->suncalc_timeout_tag);
        gw_applet->suncalc_timeout_tag = 0;
     }
 	
@@ -394,18 +394,18 @@ update_finish (WeatherInfo *info, gpointer data)
 
     /* Update timer */
     if (gw_applet->timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->timeout_tag);
+        g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
     {
 	gw_applet->timeout_tag =
-		gtk_timeout_add (
+		g_timeout_add (
                        gw_applet->gweather_pref.update_interval * 1000,
                         timeout_cb, gw_applet);
 
         nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
         if (nxtSunEvent >= 0)
             gw_applet->suncalc_timeout_tag =
-                        gtk_timeout_add (nxtSunEvent * 1000,
+                        g_timeout_add (nxtSunEvent * 1000,
                                 suncalc_timeout_cb, gw_applet);
     }
 
