@@ -210,7 +210,7 @@ applet_change_bg_cb (PanelApplet *panel_applet,
 	gtk_widget_set_style (GTK_WIDGET (applet->w_applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (applet->w_applet), rc_style);
-	gtk_rc_style_unref (rc_style);
+	g_object_unref (rc_style);
 
 	switch (type)
 	{
